class SizeVariables:
    @classmethod
    def CreateExCheckTemplate(cls):
        cls.INTAG = None
        return cls

